==> ben-2.08.tar.gz: ben/common.h <==
/*
    This file is part of ben -- a task scheduler for distributed computations
    Copyright (C) 2012-2019  Laurent Poirrier

    ben is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef BEN_COMMON_H
#define BEN_COMMON_H


#define PROTO_SV_MAGIC		0xf5ae92bd
#define PROTO_SV_RUN		0x00000001
#define PROTO_SV_STOP		0x00000002
#define PROTO_SV_PING		0x00000003

#define PROTO_SV_MSG		0x00000004
#define PROTO_SV_OUT		0x00000005
#define PROTO_SV_ERR		0x00000006
#define PROTO_SV_JOB		0x00000007
#define PROTO_SV_NODE		0x00000008

#define PROTO_CL_MAGIC		0x5d8c25b4
#define PROTO_CL_SETUP		0x00000001
#define PROTO_CL_OUT		0x00000002
#define PROTO_CL_ERR		0x00000003
#define PROTO_CL_END		0x00000004
#define PROTO_CL_PONG		0x00000005

#define PROTO_CL_ADD		0x00000006
#define PROTO_CL_RM		0x00000007
#define PROTO_CL_REQACK		0x00000008
#define PROTO_CL_EXEC		0x00000009
#define PROTO_CL_SCALE		0x0000000a
#define PROTO_CL_LIST		0x0000000b
#define PROTO_CL_NODES		0x0000000c
#define PROTO_CL_EXIT		0x0000000d

// PROTO_CL_END retcodes:
#define PROTO_END_DONE		0
#define PROTO_END_STOP		1
#define PROTO_END_FAIL		2

// PROTO_CL_LIST flags:
#define PROTO_TASK_DONE		0x0001
#define PROTO_TASK_RUNNING	0x0002
#define PROTO_TASK_PENDING	0x0004

// PROTO_CL_SCALE and PROTO_CL_EXIT flags:
#define PROTO_SCALE_KILL	0x0400
#define PROTO_SCALE_RETIRE	0x0800

// passed by main to client and server
#define BEN_FLAG_DAEMONIZE	0x00010000
#define BEN_FLAG_DURATIONS	0x00020000
#define BEN_FLAG_TIMES		0x00040000
#define BEN_FLAG_BRIDGE		0x00080000

// printed by ben client
#define BEN_CLIENT_ACK_STR	"ben: connected"

/*

server -> client:

	RUN, taskid, shell, dir, opts, name, cmd
	STOP, taskid

	control:
	
	MSG, data
	OUT, taskid, clientid, clientname, data
	ERR, taskid, clientid, clientname, data
	
client -> server:

	SETUP, cores, name
	OUT, taskid, data
	ERR, taskid, data
	END, taskid, retcode

	control:

	ADD, shell, dir, opts, name, cmd
	RM, flags, dir, name
	REQACK			[server HUPs]
	EXEC, shell, opts, cmd	[server HUPs]
	LIST, flags		[server HUPs]
	NODES			[server HUPs]

*/


#endif

==> ben-2.17.tar.gz: ben/common.h <==
/*
    This file is part of ben -- a task scheduler for distributed computations
    Copyright (C) 2012-2023  Laurent Poirrier

    ben is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef BEN_COMMON_H
#define BEN_COMMON_H


#define PROTO_SV_MAGIC		0xf5ae92bd
#define PROTO_SV_RUN		0x00000001
#define PROTO_SV_STOP		0x00000002
#define PROTO_SV_PING		0x00000003

#define PROTO_SV_MSG		0x00000004
#define PROTO_SV_OUT		0x00000005
#define PROTO_SV_ERR		0x00000006
#define PROTO_SV_JOB		0x00000007
#define PROTO_SV_NODE		0x00000008

#define PROTO_CL_MAGIC		0x5d8c25b4
#define PROTO_CL_SETUP		0x00000001
#define PROTO_CL_OUT		0x00000002
#define PROTO_CL_ERR		0x00000003
#define PROTO_CL_END		0x00000004
#define PROTO_CL_PONG		0x00000005

#define PROTO_CL_ADD		0x00000006
#define PROTO_CL_RM		0x00000007
#define PROTO_CL_REQACK		0x00000008
#define PROTO_CL_EXEC		0x00000009
#define PROTO_CL_SCALE		0x0000000a
#define PROTO_CL_LIST		0x0000000b
#define PROTO_CL_NODES		0x0000000c
#define PROTO_CL_EXIT		0x0000000d
#define PROTO_CL_RESUME		0x0000000e

// PROTO_CL_END retcodes:
#define PROTO_END_DONE		0
#define PROTO_END_STOP		1
#define PROTO_END_FAIL		2

// PROTO_CL_LIST flags:
#define PROTO_TASK_DONE		0x0001
#define PROTO_TASK_RUNNING	0x0002
#define PROTO_TASK_PENDING	0x0004

// PROTO_CL_SCALE and PROTO_CL_EXIT flags:
#define PROTO_SCALE_KILL	0x0400
#define PROTO_SCALE_RETIRE	0x0800

// passed by main to client and server
#define BEN_FLAG_DAEMONIZE	0x00010000
#define BEN_FLAG_VERBOSE	0x00020000
#define BEN_FLAG_DURATIONS	0x00040000
#define BEN_FLAG_TIMES		0x00080000
#define BEN_FLAG_GATHER		0x00100000
#define BEN_FLAG_BRIDGE		0x00200000

// printed by ben client
#define BEN_CLIENT_ACK_STR	"ben: connected"

/*

server -> client:

	RUN, taskid, shell, dir, opts, name, cmd
	STOP, taskid

	control:
	
	MSG, data
	OUT, taskid, clientid, clientname, data
	ERR, taskid, clientid, clientname, data
	
client -> server:

	SETUP, cores, name
	OUT, taskid, data
	ERR, taskid, data
	END, taskid, retcode

	control:

	ADD, shell, dir, opts, name, cmd
	RM, flags, dir, name
	LIST, flags, dir, name
	REQACK			[server HUPs]
	EXEC, shell, opts, cmd	[server HUPs]
	NODES			[server HUPs]

*/


#endif
